==> mobGameSDK-FT.2.4.4.1.AS-sources.jar: com/mobgame/utils/Constants.java <==
package com.mobgame.utils;

public class Constants {
	
	public static final String SDK_VERSION = "FT.2.4.3.AS";
	public static final String INTENT_FILTER = "com.mobgame.broadcast";
	
	public static final String LANG_CN = "zh_cn";
	public static final String LANG_EN = "eng";
	public static final String LANG_ES = "es_es";
	public static final String LANG_TH = "tha";
	public static final String LANG_VI = "vie";
	public static final String LANG_ID = "ind";
	
	/** GENERAL CONFIG **/
	public static String DOMAIN_NAME = "a.smobgame.com";
	public static String BASE_URL_DOMAIN = "http://" + DOMAIN_NAME + "/plf";
//	public static String DOMAIN_NAME = "dev.smobgame.com";
//	public static String BASE_URL_DOMAIN = "http://" + DOMAIN_NAME + "";
//	public static String DOMAIN_NAME = "192.168.3.151:8088";
//	public static String DOMAIN_NAME ="192.168.3.160:8088";//quang anh
//	public static String BASE_URL_DOMAIN = "http://" + DOMAIN_NAME + "/platform";
	// END GENERAL CONFIG

	/** URL **/
	public static final String URL_USER = BASE_URL_DOMAIN + "/users";
	public static final String URL_LOGIN_GOOGLE_PLAY = BASE_URL_DOMAIN + "/users/login_googlePlay";
	public static final String URL_LOGIN_GOOGLE_ACCOUNT = BASE_URL_DOMAIN + "/users/login_google";
	public static final String URL_RECEIVE_MAC_ADDRESS = BASE_URL_DOMAIN + "/users/reveiceMacAddress";
	public static final String URL_RECEIVE_ACCESS_TOKEN = BASE_URL_DOMAIN + "/users/reveiceAccessTokenV2";
	public static final String URL_UPDATE_FROM_FACEBOOK = BASE_URL_DOMAIN + "/users/updateFromFacebookV2";
	public static final String URL_PAYMENT = BASE_URL_DOMAIN + "/payments/pay";
	public static final String URL_SOCIAL = BASE_URL_DOMAIN + "/uncommon/dashboard_v2/gift1.html";

	public static final String URL_SAVE_CHARACTER = BASE_URL_DOMAIN + "/Oauthv2/saveCharacter.json";
	public static final String URL_SAVE_GCM = BASE_URL_DOMAIN + "/Oauthv2/saveGCM.json";
	public static final String URL_RECEIVE_IAB_RECEIPT = BASE_URL_DOMAIN + "/payments/googleRetrieveReceipt.json";
	public static final String URL_RECEIVE_PAYPAL_RECEIPT = BASE_URL_DOMAIN + "/payments/paypalRetrieveReceipt.json";
	public static final String URL_GET_GAME_V2 = BASE_URL_DOMAIN + "/Oauthv2/getInfoBeforeAuthenv3.json"; // getGamev2.json
	public static final String URL_INFO_AFTER_V2 = BASE_URL_DOMAIN + "/Oauthv2/getInfoAfterAuthenv3.json"; // getInfoAfterv2.json
	
	public static final String URL_UPLOAD_ISSUE_IMAGE = BASE_URL_DOMAIN + "/problems/uploadImageIssue.json";		
	// END URL
	
	/** SHARED PREFERENCE **/
	public static final String SHARED_PREF_MAIN_ACTIVITY = "shared_pref_main_activity";
	public static final String SHARED_PREF_DB_ENABLED = "shared_pref_db_enabled";
	public static final String SHARED_PREF_FLOATBUTTON_ENABLED = "shared_pref_float_button_enabled";
	
	public static final String SHARED_PREF_REFERRER = "shared_pref_referrer";

	public static final String SHARED_PREF_NOTIFICATONS = "shared_pref_notificatons";
	public static final String SHARED_PREF_SHOW_ADS = "shared_pref_show_ads";

	public static final String SHARED_PREF_FLOAT_BUTTON_DISMISS_TIME = "shared_pref_float_button_dismiss_time";	
	public static final String SHARED_PREF_FLOAT_BUTTON_SHOW_DIALOG = "shared_pref_float_button_show_dialog";
	public static final String SHARED_PREF_HIDE_FLOAT_BUTTON = "shared_pref_hide_float_button";
	
	public static final String SHARED_PREF_COOKIES = "shared_pref_cookies";
	// END SHARED PREFERENCE
	
	/** REQUEST CODE **/
	public static final int REQUEST_CODE_LOGIN_PLAY_SERVICES = 0;
	public static final int REQUEST_CODE_GOOGLE_IN_APP_BILLING = 10001;
	public static final int REQUEST_CODE_FACEBOOK_LOGIN = 64206;
	public static final int REQUEST_CODE_FACEBOOK_SHARE = 64207;
	public static final int REQUEST_CODE_FACEBOOK_INVITE = 64213;
	public static final int REQUEST_CODE_PICKER = 20002;
	
//	public static final int REQUEST_CODE_PAYPAL_PAYMENT = 1;
//    public static final int REQUEST_CODE_PAYPAL_FUTURE_PAYMENT = 2;
//    public static final int REQUEST_CODE_PAYPAL_PROFILE_SHARING = 3;
	// REQUEST CODE

    /** HTTP HEADERS **/
	public static final String MOBGAME_APPKEY = "mobgame-appkey";
	public static final String MOBGAME_TOKEN = "mobgame-token";
	public static final String MOBGAME_OS = "mobgame-os";
	public static final String MOBGAME_RESOLUTION = "mobgame-resolution";
	public static final String MOBGAME_APP_VERSION = "mobgame-app-version";
	public static final String MOBGAME_APP_VERSION_CODE = "mobgame-app-version-code";
	public static final String MOBGAME_NETWORK = "mobgame-network";
	public static final String MOBGAME_DEVICE = "mobgame-device";
	public static final String MOBGAME_SDK_VERSION = "mobgame-sdk-version";
	public static final String MOBGAME_ROLEID = "mobgame-role-id";
	public static final String MOBGAME_AREAID = "mobgame-area-id";
	public static final String MOBGAME_ROLENAME = "mobgame-role-name";
	public static final String MOBGAME_AREANAME = "mobgame-area-name";
	public static final String MOBGAME_ADVERTISING_ID = "mobgame-advertising-id";
	public static final String MOBGAME_ORIENTATION = "mobgame-orientation";
	public static final String MOBGAME_REFERRER = "mobgame-distributor";
	// HTTP HEADERS

}

==> mobGameSDK-FT.2.4.4.2.AS-sources.jar: com/mobgame/utils/Constants.java <==
package com.mobgame.utils;

public class Constants {
	
	public static final String SDK_VERSION = "ft.2.4.4.2.as";
	public static final String INTENT_FILTER = "com.mobgame.broadcast";
	
	public static final String LANG_CN = "zh_cn";
	public static final String LANG_EN = "eng";
	public static final String LANG_ES = "es_es";
	public static final String LANG_TH = "tha";
	public static final String LANG_VI = "vie";
	public static final String LANG_ID = "ind";
	
	/** GENERAL CONFIG **/
	public static String DOMAIN_NAME = "a.smobgame.com";
	public static String BASE_URL_DOMAIN = "http://" + DOMAIN_NAME + "/plf";
//	public static String DOMAIN_NAME = "dev.smobgame.com";
//	public static String BASE_URL_DOMAIN = "http://" + DOMAIN_NAME + "";
//	public static String DOMAIN_NAME = "192.168.3.151:8088";
//	public static String DOMAIN_NAME ="192.168.3.160:8088";//quang anh
//	public static String BASE_URL_DOMAIN = "http://" + DOMAIN_NAME + "/platform";
	// END GENERAL CONFIG

	/** URL **/
	public static final String URL_USER = BASE_URL_DOMAIN + "/users";
	public static final String URL_LOGIN_GOOGLE_PLAY = BASE_URL_DOMAIN + "/users/login_googlePlay";
	public static final String URL_LOGIN_GOOGLE_ACCOUNT = BASE_URL_DOMAIN + "/users/login_google";
	public static final String URL_RECEIVE_MAC_ADDRESS = BASE_URL_DOMAIN + "/users/reveiceMacAddress";
	public static final String URL_RECEIVE_ACCESS_TOKEN = BASE_URL_DOMAIN + "/users/reveiceAccessTokenV2";
	public static final String URL_UPDATE_FROM_FACEBOOK = BASE_URL_DOMAIN + "/users/updateFromFacebookV2";
	public static final String URL_PAYMENT = BASE_URL_DOMAIN + "/payments/pay";
	public static final String URL_SOCIAL = BASE_URL_DOMAIN + "/uncommon/dashboard_v2/gift1.html";

	public static final String URL_SAVE_CHARACTER = BASE_URL_DOMAIN + "/Oauthv2/saveCharacter.json";
	public static final String URL_SAVE_GCM = BASE_URL_DOMAIN + "/Oauthv2/saveGCM.json";
	public static final String URL_RECEIVE_IAB_RECEIPT = BASE_URL_DOMAIN + "/payments/googleRetrieveReceipt.json";
	public static final String URL_RECEIVE_PAYPAL_RECEIPT = BASE_URL_DOMAIN + "/payments/paypalRetrieveReceipt.json";
	public static final String URL_GET_GAME_V2 = BASE_URL_DOMAIN + "/Oauthv2/getInfoBeforeAuthenv3.json"; // getGamev2.json
	public static final String URL_INFO_AFTER_V2 = BASE_URL_DOMAIN + "/Oauthv2/getInfoAfterAuthenv3.json"; // getInfoAfterv2.json
	
	public static final String URL_UPLOAD_ISSUE_IMAGE = BASE_URL_DOMAIN + "/problems/uploadImageIssue.json";		
	// END URL
	
	/** SHARED PREFERENCE **/
	public static final String SHARED_PREF_MAIN_ACTIVITY = "shared_pref_main_activity";
	public static final String SHARED_PREF_DB_ENABLED = "shared_pref_db_enabled";
	public static final String SHARED_PREF_FLOATBUTTON_ENABLED = "shared_pref_float_button_enabled";
	
	public static final String SHARED_PREF_REFERRER = "shared_pref_referrer";

	public static final String SHARED_PREF_NOTIFICATONS = "shared_pref_notificatons";
	public static final String SHARED_PREF_SHOW_ADS = "shared_pref_show_ads";

	public static final String SHARED_PREF_FLOAT_BUTTON_DISMISS_TIME = "shared_pref_float_button_dismiss_time";	
	public static final String SHARED_PREF_FLOAT_BUTTON_SHOW_DIALOG = "shared_pref_float_button_show_dialog";
	public static final String SHARED_PREF_HIDE_FLOAT_BUTTON = "shared_pref_hide_float_button";
	
	public static final String SHARED_PREF_COOKIES = "shared_pref_cookies";
	// END SHARED PREFERENCE
	
	/** REQUEST CODE **/
	public static final int REQUEST_CODE_LOGIN_PLAY_SERVICES = 0;
	public static final int REQUEST_CODE_GOOGLE_IN_APP_BILLING = 10001;
	public static final int REQUEST_CODE_FACEBOOK_LOGIN = 64206;
	public static final int REQUEST_CODE_FACEBOOK_SHARE = 64207;
	public static final int REQUEST_CODE_FACEBOOK_INVITE = 64213;
	public static final int REQUEST_CODE_PICKER = 20002;
	
//	public static final int REQUEST_CODE_PAYPAL_PAYMENT = 1;
//    public static final int REQUEST_CODE_PAYPAL_FUTURE_PAYMENT = 2;
//    public static final int REQUEST_CODE_PAYPAL_PROFILE_SHARING = 3;
	// REQUEST CODE

    /** HTTP HEADERS **/
	public static final String MOBGAME_APPKEY = "mobgame-appkey";
	public static final String MOBGAME_TOKEN = "mobgame-token";
	public static final String MOBGAME_OS = "mobgame-os";
	public static final String MOBGAME_RESOLUTION = "mobgame-resolution";
	public static final String MOBGAME_APP_VERSION = "mobgame-app-version";
	public static final String MOBGAME_APP_VERSION_CODE = "mobgame-app-version-code";
	public static final String MOBGAME_NETWORK = "mobgame-network";
	public static final String MOBGAME_DEVICE = "mobgame-device";
	public static final String MOBGAME_SDK_VERSION = "mobgame-sdk-version";
	public static final String MOBGAME_ROLEID = "mobgame-role-id";
	public static final String MOBGAME_AREAID = "mobgame-area-id";
	public static final String MOBGAME_ROLENAME = "mobgame-role-name";
	public static final String MOBGAME_AREANAME = "mobgame-area-name";
	public static final String MOBGAME_ADVERTISING_ID = "mobgame-advertising-id";
	public static final String MOBGAME_ORIENTATION = "mobgame-orientation";
	public static final String MOBGAME_REFERRER = "mobgame-distributor";
	// HTTP HEADERS

}
